[−][src]Enum vimwiki::lang::RawStr
Represents a raw string for a type of language (vimwiki, markdown, mediawiki)
Variants
Vimwiki(&'a str)Markdown(&'a str)Mediawiki(&'a str)Trait Implementations
impl<'a> Clone for RawStr<'a>[src]
impl<'a> Debug for RawStr<'a>[src]
impl<'a> Display for RawStr<'a>[src]
impl<'a> Eq for RawStr<'a>[src]
impl<'a> PartialEq<RawStr<'a>> for RawStr<'a>[src]
impl<'a> StructuralEq for RawStr<'a>[src]
impl<'a> StructuralPartialEq for RawStr<'a>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<Page>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<BlockComponent>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<ExternalFileLink>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<RawLink>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<TransclusionLink>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<WikiLink>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<InterWikiLink>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<List>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<MathInline>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<MathBlock>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<Paragraph>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<PreformattedText>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<InlineComponentContainer>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<Table>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<Tags>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<String>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<DecoratedText>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<Keyword>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<InlineComponent>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<Blockquote>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<DefinitionList>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<Divider>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<Header>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<Link>[src]
type Error = LangParserError
The type returned in the event of a conversion error.
fn try_from(s: RawStr<'a>) -> Result<Self, Self::Error>[src]
impl<'a> TryFrom<RawStr<'a>> for LC<DiaryLink>[src]