[−][src]Struct vimwiki::elements::Table
Fields
rows: Vec<Located<Row<'a>>>centered: boolImplementations
impl<'a> Table<'a>[src]
impl<'_> Table<'_>[src]
pub fn to_borrowed(&self) -> Table<'_>[src]
pub fn into_owned(self) -> Table<'static>[src]
impl<'a> Table<'a>[src]
pub fn get_column_alignment(&self, col: usize) -> ColumnAlign[src]
Returns the alignment of the specified column within the table
NOTE: This will always return an alignment, even if the column does not exist, by using the default column alignment
pub fn get_cell(&self, row: usize, col: usize) -> Option<&Located<Cell<'a>>>[src]
Returns reference to the cell found at the specified row and column
pub fn into_children(self) -> Vec<Located<InlineElement<'a>>>[src]