[−][src]Struct vimwiki::lang::components::WikiLink
Represents a link to a file or directory in the active wiki
Fields
path: PathBufdescription: Option<Description>anchor: Option<Anchor>Implementations
impl WikiLink[src]
pub fn new(
path: PathBuf,
description: Option<Description>,
anchor: Option<Anchor>
) -> WikiLink[src]
path: PathBuf,
description: Option<Description>,
anchor: Option<Anchor>
) -> WikiLink
impl WikiLink[src]
pub fn is_local_anchor(&self) -> bool[src]
Whether or not the link is representing an anchor to the current page
pub fn is_path_dir(&self) -> bool[src]
Checks if the link's path is to a directory without actually evaluating in the filesystem. Only checks if the path appears as that of a directory