[−][src]Module vimwiki::lang::elements
Structs
| Anchor | Represents an anchor |
| Blockquote | |
| DecoratedText | Represents text (series of content) with a typeface decoration |
| DefinitionList | Represents a list of terms and definitions, where a term can have multiple definitions associated with it |
| DiaryLink | Represents a link to an entry in the diary wiki |
| Divider | |
| ExternalFileLink | Represents an external link to some file or directory on the host system |
| Header | |
| IndexedInterWikiLink | Represents a link to a file or directory in another wiki specified by an index that maps to the g:vimwiki_list |
| InlineElementContainer | Represents a convenience wrapper around a series of inline elements |
| LineComment | |
| List | Represents a regular list comprised of individual items |
| ListItem | Represents an item in a list |
| ListItemAttributes | Represents additional attributes associated with a list item |
| ListItemContents | Represents a collection of list item content |
| MathBlock | |
| MathInline | |
| MultiLineComment | |
| NamedInterWikiLink | Represents a link to a file or directory in another wiki specified by a name that maps to the name key in g:vimwiki_list |
| Page | Represents a full page containing different elements |
| Paragraph | |
| PreformattedText | |
| RawLink | Represents a raw link in the form of http[s]://example.com |
| Table | |
| Tag | Represents a single tag |
| Tags | Represents a sequence of one or more tags |
| TermAndDefinitions | Represents a term and associated definitions |
| TransclusionLink | Represents a link that is used as a "Wiki Include" to pull in resources |
| WikiLink | Represents a link to a file or directory in the active wiki |
Enums
| BlockElement | Represents elements that are standalone (metaphorically a block element in CSS) |
| Cell | |
| Comment | |
| DecoratedTextContent | Represents content that can be contained within a decoration |
| Decoration | Represents a typeface decoration that can be applied to text |
| Description | Represents a description for a link |
| ExternalFileLinkScheme | Represents the scheme associated with the external file link |
| InlineElement | Represents elements that can be dropped into other elements |
| InterWikiLink | Represents a link to a file or directory in another wiki |
| Keyword | Represents special keywords that have unique syntax highlighting |
| Link | |
| ListItemContent | Represents some content associated with a list item, either being an inline element or a new sublist |
| ListItemSuffix | Represents a suffix such as . or ) used after beginning of list item |
| ListItemTodoStatus | Represents the todo status for a list item |
| ListItemType | |
| OrderedListItemType | Represents the type associated with an ordered item |
| Placeholder | |
| Row | |
| UnorderedListItemType | Represents the type associated with an unordered item |
Type Definitions
| Definition | Represents the type used for a single definition |
| Term | Represents the type used for a single term |